@@ -2,6 +2,6 @@
 # Configuration file for using the xslt library
 #
 XSLT_LIBDIR="-L/usr/lib"
-XSLT_LIBS="-lxslt  -L/usr/lib -lxml2 -lz -lpthread -lm -lm"
+XSLT_LIBS="-lxslt  -L/usr/lib -lxml2 -lz -lm -lm"
 XSLT_INCLUDEDIR="-I/usr/include"
-MODULE_VERSION="xslt-1.1.6"
+MODULE_VERSION="xslt-1.1.20"
